##############
Config modules
##############

Each module has its own separate tab with various options. These are generally pretty self-explanatory, and there
aren't too many of them

.. image:: ../images/config_modules.png
